phoneCode property
The phone number prefix for this country, like 93 for Afghanistan
Implementation
@JsonKey(name: 'phone_code')
final String phoneCode;
The phone number prefix for this country, like 93 for Afghanistan
@JsonKey(name: 'phone_code')
final String phoneCode;